

SSAQuery
=====================

.. currentmodule:: pyvo.dal.ssa

.. autoclass:: SSAQuery
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SSAQuery.band
      ~SSAQuery.dec
      ~SSAQuery.format
      ~SSAQuery.pos
      ~SSAQuery.ra
      ~SSAQuery.size
      ~SSAQuery.std_parameters
      ~SSAQuery.time

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: band
   .. autoattribute:: dec
   .. autoattribute:: format
   .. autoattribute:: pos
   .. autoattribute:: ra
   .. autoattribute:: size
   .. autoattribute:: std_parameters
   .. autoattribute:: time

   
   

   
   
   